@@ -1,7 +1,6 @@
 #!/usr/bin/python
 
 import curses
-import os
 
 class ResizeError(Exception):
     "The screen has been resized"
@@ -26,7 +25,7 @@ def CallSubShell(subshell):
     
     rtn = os.system("%s" % (subshell))
     curses.reset_prog_mode()
-    if rtn is not 0: return False
+    if rtn != 0: return False
     else: return True
 
     curses.reset_prog_mode()
